pub fn construct_instance(obj: UObjectHandle, type_id: u64)Expand description
Construct a Rust instance for a newly created UObject.
Called from the C++ class constructor via construct_rust_instance callback.
pub fn construct_instance(obj: UObjectHandle, type_id: u64)Construct a Rust instance for a newly created UObject.
Called from the C++ class constructor via construct_rust_instance callback.