pub fn drop_instance(obj: UObjectHandle, _type_id: u64)Expand description
Drop and remove the Rust instance for a destroyed UObject.
Called from the C++ delete listener via drop_rust_instance callback.
pub fn drop_instance(obj: UObjectHandle, _type_id: u64)Drop and remove the Rust instance for a destroyed UObject.
Called from the C++ delete listener via drop_rust_instance callback.