ValidHandle

Trait ValidHandle 

pub trait ValidHandle {
    // Required method
    fn handle(&self) -> UObjectHandle;
}
Trait for types that have been pre-validated and can provide a handle without fallibility. Checked<T> and Pinned<T> implement this.

Codegen extension traits use this as a supertrait so that methods return T directly instead of UikaResult<T>.

Required Methods

fn handle(&self) -> UObjectHandle

Return the raw handle. The implementor guarantees (or debug-asserts) that the handle is valid.

Implementors